/* global BdfApi,FicheQL */

/**
 * @constructor
  */
 BdfApi.Wrapper = function () {
    this.thesaurusMap = new Map();
    this.fichesMap = new Map();
};

BdfApi.Wrapper.prototype.getThesaurus = function (key) {
    return this.thesaurusMap.get(key);
};

BdfApi.Wrapper.prototype.getFiches = function (key) {
    return this.fichesMap.get(key);
};

BdfApi.Wrapper.prototype.initThesaurus = function (config, thesaurusName, options) {
    var thesaurusMap = this.thesaurusMap;
    var thesaurusKey = thesaurusName;
    if ((options) && (options.thesaurusKey)) {
        thesaurusKey = options.thesaurusKey;
    }
    var requestParameters = {};
    if (options) {
        if (options.thesaurusKey) {
            thesaurusKey = options.thesaurusKey;
        }
        if (options.propertiesMapping) {
            requestParameters.tableexport = options.propertiesMapping;
        }
    }
    return function (callback) {
        BdfApi.Ajax.loadThesaurus(config, thesaurusName, {
            requestParameters: requestParameters,
            callback: function (data) {
                let wrapper = new BdfApi.Wrapper.Thesaurus(data);
                thesaurusMap.set(thesaurusKey, wrapper);
                if (callback) {
                    callback();
                }
            }
        });
    };
};

BdfApi.Wrapper.prototype.initFiches = function (config, fichesKey, options) {
    var fichesMap = this.fichesMap;
    var uniqueCorpus = false;
    var requestParameters = {};
    var ficheQL = null;
    if (options) {
        if (options.propertiesMapping) {
            requestParameters.tableexport = options.propertiesMapping;
        }
        if (options.ficheQL) {
            ficheQL = options.ficheQL;
        } else if (options.ql) {
            ficheQL = new FicheQL.Fiche(options.ql);
        }
        if (options.uniqueCorpus) {
            uniqueCorpus = true;
        }
    }
    if (!ficheQL) {
        uniqueCorpus = true;
        ficheQL = new FicheQL.Fiche({
            corpus: fichesKey
        });
    }
    return function (callback) {
        BdfApi.Ajax.loadFicheArray(config, ficheQL, {
            requestParameters: requestParameters,
            callback: function (data) {
                let wrapper = new BdfApi.Wrapper.Fiches(data, uniqueCorpus);
                fichesMap.set(fichesKey, wrapper);
                if (callback) {
                    callback();
                }
            }
        });
    };
};

BdfApi.Wrapper.Thesaurus = function (thesaurusApiData) {
    var idMap = new Map();
    var idalphaMap = new Map();
    this.apiData = thesaurusApiData;
    this.idMap = idMap;
    this.idalphaMap = idalphaMap;
    _populate(thesaurusApiData.thesaurus.firstLevelArray);


    function _populate(array) {
        for(let motcle of array) {
            idMap.set(motcle.id, motcle);
            if (motcle.idalpha) {
                idalphaMap.set(motcle.idalpha, motcle);
            }
            _populate(motcle.childArray);
        }
    }
    
};

BdfApi.Wrapper.Thesaurus.prototype.getName = function () {
    return this.apiData.thesaurus.name;
};

BdfApi.Wrapper.Thesaurus.prototype.getFirstLevelArray = function () {
    return this.apiData.thesaurus.firstLevelArray;
};

BdfApi.Wrapper.Thesaurus.prototype.getMotcleById = function (id) {
	return this.idMap.get(id);
};

BdfApi.Wrapper.Thesaurus.prototype.getMotcleByIdalpha = function (idalpha) {
    return this.idalphaMap.get(idalpha);
};

BdfApi.Wrapper.Thesaurus.prototype.complete = function (completeFunction) {
    for(let motcle of this.idMap.values()) {
        completeFunction(motcle);
    }
};

BdfApi.Wrapper.Thesaurus.prototype.toMotcleArray = function () {
    var array = new Array();
    for(let motcle of this.idMap.values()) {
        array.push(motcle);
    }
    return array;
};

BdfApi.Wrapper.Fiches = function (ficheArrayApiData, uniqueCorpus) {
    this.apiData = ficheArrayApiData;
    this.uniqueCorpus = uniqueCorpus;
    var codeMap = new Map();
    var idMap = new Map();
    this.codeMap = codeMap;
    this.idMap = idMap;
    for(let ficheApiData of ficheArrayApiData.array) {
        codeMap.set(ficheApiData.code, ficheApiData);
        if (uniqueCorpus) {
            idMap.set(ficheApiData.id, ficheApiData);
        }
    }
};

BdfApi.Wrapper.Fiches.prototype.getFiche = function (corpus, id) {
    return this.codeMap.get(corpus + "/" + id);
};

BdfApi.Wrapper.Fiches.prototype.getFicheById = function (id) {
    return this.idMap.get(id);
};

BdfApi.Wrapper.Fiches.prototype.getFicheArray = function () {
    return this.apiData.array;
};

BdfApi.Wrapper.Fiches.prototype.complete = function (completeFunction) {
    for(let fiche of this.idMap.values()) {
        completeFunction(fiche);
    }
};
